@@ -95,6 +95,15 @@ class LdapSimpleTestCase(unittest.TestCase):
         )
         self.assertFalse(result)
 
+    @defer.inlineCallbacks
+    def test_uppercase_username(self):
+        result = yield defer.ensureDeferred(
+            self.auth_provider.check_auth(
+                "BOB", "m.login.password", {"password": "secret"}
+            )
+        )
+        self.assertEqual(result, "@bob:test")
+
 
 class LdapSearchTestCase(unittest.TestCase):
     @defer.inlineCallbacks
